@@ -1,6 +1,6 @@
 #!/bin/sh
 # cd /usr/lib/hildon-desktop
-# python2.5 recaller2.py
+# python2.5 recaller.py
 
 import gobject
 import gtk
@@ -112,41 +112,49 @@ class Recaller2HomePlugin(hildondesktop.HomePluginItem):
     screen = self.get_screen()
     colormap = screen.get_rgba_colormap()
     self.set_colormap(colormap)
-    hildondesktop.HomePluginItem.do_realize(self)
-   
+    hildondesktop.HomePluginItem.do_realize(self) 
 
   def on_toggled(self, button, data=None):
     if self.isStopped==True:
-      #Button got activated, start the recording
-      self.isStopped=False
       self.draw_e_on()
+      #Button got activated, start the recording
+      banner = hildon.hildon_banner_show_information(self, "", "recaller: Recording is starting.")
+      self.isStopped=False
       self.startTime =  time.strftime("%Y%m%d_%H%M%S")
+      self.startTimeToDisplay =  time.strftime("%H:%M:%S")
       self.fileName = "/home/user/MyDocs/Rec_%s.aac" % self.startTime
       print self.fileName
-      self.player = gst.parse_launch ("adder name=theAdder ! nokiaaacenc bitrate=128000 output-format=2 ! filesink location=%s. pulsesrc device=sink.hw0.monitor ! queue ! theAdder. pulsesrc device=source.hw0 ! queue ! theAdder." % self.fileName)
-      self.player.set_state(gst.STATE_PLAYING)
-      banner = hildon.hildon_banner_show_information(self, "", "recaller: Conversation recording has started.")
-      banner.set_timeout(2000)
-      print "recaller: " + time.strftime("%H:%M:%S") + " - Conversation started."
+      self.recorder = gst.parse_launch ("adder name=theAdder ! nokiaaacenc bitrate=128000 output-format=2 ! filesink location=%s. pulsesrc device=sink.hw0.monitor ! queue name=q1 ! theAdder. pulsesrc device=source.hw0 ! queue name=q2 ! theAdder." % self.fileName)
+      bus = self.recorder.get_bus()
+      bus.add_signal_watch()
+      bus.enable_sync_message_emission()
+      bus.connect("message", self.on_message)
+      bus.connect("sync-message::element", self.on_sync_message)
+      self.recorder.set_state(gst.STATE_PLAYING)
+      self.timer = gobject.timeout_add_seconds(30, self.recordingreminder_cb)      
+      banner = hildon.hildon_banner_show_information(self, "", "recaller: Recording has started.")
+      print "recaller: " + time.strftime("%H:%M:%S") + " - Recording started."
     else:
       #Button got deactivated. stop the recording
-      self.draw_e_off()
-      self.player.set_state(gst.STATE_NULL)
+      gobject.source_remove(self.timer)
+      self.draw_e_off()    
+      banner = hildon.hildon_banner_show_information(self, "", "recaller: Recording is stopping.")  
+      self.recorder.send_event(gst.event_new_eos())
+      #self.recorder.set_state(gst.STATE_NULL)
       finalName = "/home/user/MyDocs/Rec_%s-%s.aac" % (self.startTime, time.strftime("%H%M%S"))
       print finalName 
-      time.sleep(2)
+      #time.sleep(2)
       os.rename(self.fileName, finalName)
-      banner = hildon.hildon_banner_show_information(self, "", "recaller: Conversation recording was stopped.")
-      banner.set_timeout(2000)
+      banner = hildon.hildon_banner_show_information(self, "", "recaller: Recording was stopped.")
       self.isStopped=True
-      print "recaller: " + time.strftime("%H:%M:%S") + " - Conversation stopped."   
+      print "recaller: " + time.strftime("%H:%M:%S") + " - Recording stopped."   
 
   def on_message(self, bus, message):
     t = message.type
     if t == gst.MESSAGE_EOS:
-      self.player.set_state(gst.STATE_NULL)
+      self.recorder.set_state(gst.STATE_NULL)
     elif t == gst.MESSAGE_ERROR:
-      self.player.set_state(gst.STATE_NULL)
+      self.recorder.set_state(gst.STATE_NULL)
     #err, debug = message.parse_error()
     #print "recaller on_message: %s" % err, debug
     #banner = hildon.hildon_banner_show_information(self, "", "recaller: " + message.parse_error())
@@ -158,12 +166,12 @@ class Recaller2HomePlugin(hildondesktop.HomePluginItem):
     message_name = message.structure.get_name()
     if message_name == 'prepare-xwindow-id':
       return
-      # Assign the viewport
-      #imagesink = message.src
-      #imagesink.set_property('force-aspect-ratio', True)
-      #imagesink.set_xwindow_id(self.movie_window.window.xid)
-         
-         
+
+  def recordingreminder_cb(self):
+    banner = hildon.hildon_banner_show_information(self, "", "recaller: " + "Recording since "+self.startTimeToDisplay)
+    return True
+    
+    
 hd_plugin_type = Recaller2HomePlugin
 
 if __name__ == "__main__":
